%define build_subpixel 0
%define build_plf 0
%{?_with_plf: %global build_plf 1}
%{?_with_subpixel: %global build_subpixel 1}

%if "%distro_section" == "tainted"
%global build_plf	1
%endif

%if %build_plf
%define build_subpixel	1
%endif

%define major		6
%define libname		%mklibname freetype %{major}
%define develname	%mklibname freetype2 -d

Name:		freetype2
Summary:	A free and portable TrueType font rendering engine
Version:	2.13.0
%define subrel 2
Release:	%mkrel 1
License:	FreeType License/GPL
Group:		System/Libraries
URL:		https://www.freetype.org/
Source0:	https://downloads.sourceforge.net/freetype/freetype-%{version}.tar.xz
Source1:	https://downloads.sourceforge.net/freetype/freetype-doc-%{version}.tar.xz
Source2:	https://downloads.sourceforge.net/freetype/ft2demos-%{version}.tar.xz
# Enable subpixel rendering (ClearType)
Patch0:		freetype-2.10.1-enable-spr.patch
Patch1:		freetype-2.13.0-git-cve-2025-27363.patch

BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(harfbuzz)
BuildRequires:	pkgconfig(libbrotlidec)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(librsvg-2.0)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(zlib)

%description
The FreeType2 engine is a free and portable TrueType font rendering engine.
It has been developed to provide TT support to a great variety of
platforms and environments. Note that FreeType2 is a library, not a
stand-alone application, though some utility applications are included.
%if %{build_plf}

This package is in the "tainted" section because it has subpixel hinting
enabled which is covered by software patents.
%endif

%package -n %{libname}
Summary:	Shared libraries for a free and portable TrueType font rendering engine
Group:		System/Libraries
Provides:	%{name} = %{version}-%{release}
#include provides to allow for zoom rpm installation
Provides:	freetype = %{version}-%{release}

%description -n %{libname}
The FreeType2 engine is a free and portable TrueType font rendering
engine.  It has been developed to provide TT support to a great
variety of platforms and environments. Note that FreeType2 is a
library, not a stand-alone application, though some utility
applications are included.
%if %{build_plf}

This package is in the "tainted" section because it has subpixel hinting
enabled which is covered by software patents.
%endif

%package -n %{develname}
Summary:	Header files and static library for development with FreeType2
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	pkgconfig(zlib)
Provides:	freetype-devel = %{version}-%{release}
Provides:	freetype2-devel = %{version}-%{release}
Obsoletes:	%{_lib}freetype6-static-devel < 2.9.1-4
Obsoletes:	%{_lib}freetype6-devel < 2.9.1-4
Obsoletes:	%{_lib}freetype2-devel < 2.9.1

%description -n %{develname}
This package is only needed if you intend to develop or compile applications
which rely on the FreeType2 library. If you simply want to run existing
applications, you won't need this package.

%package demos
Summary:	A collection of FreeType demos
Group:		File tools

%description demos
The FreeType engine is a free and portable font rendering engine, developed to
provide advanced font support for a variety of platforms and environments. The
demos package includes a set of useful small utilities showing various
capabilities of the FreeType library.

%prep
%autosetup -p1 -n freetype-%version -b 1 -a2

%if %{build_subpixel}
perl -pi -e 's|^/\* #define FT_CONFIG_OPTION_SUBPIXEL_RENDERING \*/| #define FT_CONFIG_OPTION_SUBPIXEL_RENDERING|' include/freetype/config/ftoption.h
%endif

%build
%configure \
  --enable-freetype-config \
  --with-zlib=yes \
  --with-bzip2=yes \
  --with-png=yes \
  --with-harfbuzz=yes \
  --with-brotli=yes \
  --with-librsvg=yes \
  --disable-static
%make_build

pushd ft2demos-%{version}
%make_build X11_PATH=%{_prefix} TOP_DIR=".."
popd

%install
%make_install

for ftdemo in ftbench ftdiff ftdump ftgamma ftgrid ftlint ftmulti ftstring ftvalid ftview; do
    builds/unix/libtool --mode=install install -m 755 ft2demos-%{version}/bin/$ftdemo %{buildroot}%{_bindir}
done

#we don't want these
find %{buildroot} -name "*.la" -delete

%files -n %{libname}
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{major}.*

%files -n %{develname}
%doc ../freetype-%{version}/docs/*
%{_bindir}/freetype-config
%{_libdir}/*.so
%dir %{_includedir}/freetype2
%{_includedir}/freetype2/*
%{_datadir}/aclocal/*
%{_mandir}/man1/freetype-config.1*
%{_libdir}/pkgconfig/*

%files demos
%{_bindir}/ftbench
%{_bindir}/ftdiff
%{_bindir}/ftdump
%{_bindir}/ftgamma
%{_bindir}/ftgrid
%{_bindir}/ftlint
%{_bindir}/ftmulti
%{_bindir}/ftstring
%{_bindir}/ftvalid
%{_bindir}/ftview


%changelog
* Thu Mar 13 2025 danf <danf> 2.13.0-1.2.mga9
+ Revision: 2163767
- Include second part of fix for CVE-2025-27363 (mga#34095)
- Fix buffer overflow CVE-2025-27363 (mga#34095)

* Sat Feb 11 2023 kekepower <kekepower> 2.13.0-1.mga9.tainted
+ Revision: 1940120
- Update to version 2.13.0

* Sat Nov 19 2022 kekepower <kekepower> 2.12.1-4.mga9.tainted
+ Revision: 1908835
- Rebuild for harfbuzz

* Mon Aug 22 2022 ns80 <ns80> 2.12.1-3.mga9
+ Revision: 1879272
- adapt patch from Debian for CVE-2022-31782 (mga#30659)

* Mon Aug 08 2022 akien <akien> 2.12.1-2.mga9.tainted
+ Revision: 1876267
- Enable optional brotli, harfbuzz and librsvg support

* Sun May 01 2022 kekepower <kekepower> 2.12.1-1.mga9.tainted
+ Revision: 1855377
- Update to version 2.12.1

* Thu Mar 31 2022 kekepower <kekepower> 2.12.0-1.mga9.tainted
+ Revision: 1837433
- Update to version 2.12.0

* Sat Mar 19 2022 umeabot <umeabot> 2.11.1-2.mga9
+ Revision: 1800341
- Mageia 9 Mass Rebuild

* Thu Dec 02 2021 kekepower <kekepower> 2.11.1-1.mga9
+ Revision: 1760535
- Update to version 2.11.1

* Fri Jul 23 2021 kekepower <kekepower> 2.11.0-1.mga9.tainted
+ Revision: 1737523
- Update to version 2.11.0

* Thu Jan 14 2021 joequant <joequant> 2.10.4-2.mga8
+ Revision: 1671743
- add freetype provides - this allows zoom fedora rpm to install

* Tue Oct 20 2020 kekepower <kekepower> 2.10.4-1.mga8
+ Revision: 1637259
- Update to version 2.10.4

* Sun Oct 11 2020 kekepower <kekepower> 2.10.3-1.mga8
+ Revision: 1633142
- Update to version 2.10.3

* Sat May 09 2020 luigiwalser <luigiwalser> 2.10.2-1.mga8.tainted
+ Revision: 1582195
- 2.10.2

* Sat Feb 15 2020 umeabot <umeabot> 2.10.1-2.mga8.tainted
+ Revision: 1526832
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Jul 02 2019 daviddavid <daviddavid> 2.10.1-1.mga8
+ Revision: 1417518
- new version: 2.10.1
- rename and rediff enable-spr patch

* Mon Feb 18 2019 wally <wally> 2.9.1-4.mga7.tainted
+ Revision: 1368215
- rename devel pkg as freetype2-devel (and obsolete old freetype 1.x as it seems to be unused)
- provide freetype-devel
- drop multiarch support and static devel pkg

* Wed Oct 31 2018 tv <tv> 2.9.1-3.mga7
+ Revision: 1326952
- Enable ClearType code thanks to Microsoft joining OIN
- Drop no more needed mathlib patch

* Sun Sep 23 2018 umeabot <umeabot> 2.9.1-2.mga7.tainted
+ Revision: 1297783
- Mageia 7 Mass Rebuild

* Mon Jun 04 2018 kekepower <kekepower> 2.9.1-1.mga7
+ Revision: 1234447
- Update to version 2.9.1
- Remove merged patch for CVE-2018-6942
- Renamed RPM_BUILD_ROOT to buildroot

* Mon Apr 16 2018 kekepower <kekepower> 2.9-1.mga7
+ Revision: 1219365
- Update to version 2.9

* Sat Feb 17 2018 shlomif <shlomif> 2.8.1-2.mga7
+ Revision: 1202076
- Patch for MGA#22611 ; CVE-2018-6942.

* Mon Sep 25 2017 tv <tv> 2.8.1-1.mga7
+ Revision: 1159291
- use new macros

* Mon Sep 25 2017 tv <tv> 2.8.1-1.mga7.tainted
+ Revision: 1159286
- new release

* Sat Apr 29 2017 luigiwalser <luigiwalser> 2.7.1-2.mga6
+ Revision: 1098077
- add upstream patches to fix CVE-2017-8105 and CVE-2017-8287

* Fri Dec 30 2016 luigiwalser <luigiwalser> 2.7.1-1.mga6.tainted
+ Revision: 1078736
- 2.7.1

* Wed Sep 14 2016 akien <akien> 2.7-1.1.mga6.tainted
+ Revision: 1052934
- Rebuild for tainted

* Wed Sep 14 2016 tv <tv> 2.7-1.mga6
+ Revision: 1052890
- new version

* Mon Aug 29 2016 ghibo <ghibo> 2.6.5-2.mga6.tainted
+ Revision: 1049431
- Fix include path of ftoption.h in SPEC file for perl regexp (fixes bug #19263).

* Tue Jul 12 2016 luigiwalser <luigiwalser> 2.6.5-1.mga6
+ Revision: 1041270
- 2.6.5

* Tue Feb 09 2016 luigiwalser <luigiwalser> 2.6.3-1.mga6.tainted
+ Revision: 952945
- 2.6.3

* Tue Dec 01 2015 tv <tv> 2.6.2-1.mga6
+ Revision: 907452
- new release
- drop support for PPC

* Tue Oct 06 2015 fwang <fwang> 2.6.1-1.mga6.tainted
+ Revision: 886572
- fix file list
- 2.6.1

* Sat Aug 22 2015 akien <akien> 2.6-2.mga6
+ Revision: 868033
- Rebuild for gcc 5.2.1

* Wed Jul 01 2015 fwang <fwang> 2.6-1.mga6.tainted
+ Revision: 849256
- drop old patches
- 2.6

* Sat Dec 13 2014 eatdirt <eatdirt> 2.5.4-2.mga5.tainted
+ Revision: 802939
- Add upstream patch to fix mga#14785

* Tue Dec 09 2014 fwang <fwang> 2.5.4-1.mga5.tainted
+ Revision: 802399
- new version 2.5.4

* Wed Oct 15 2014 umeabot <umeabot> 2.5.3-3.mga5.tainted
+ Revision: 739929
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.5.3-2.mga5.tainted
+ Revision: 679355
- Mageia 5 Mass Rebuild

* Mon Mar 10 2014 fwang <fwang> 2.5.3-1.mga5.tainted
+ Revision: 601638
- update file list
- 2.5.3

* Fri Feb 07 2014 fwang <fwang> 2.5.2-1.mga5.tainted
+ Revision: 585050
- update include path
- update file path
- new version 2.5.2

* Mon Oct 21 2013 umeabot <umeabot> 2.5.0.1-3.mga4.tainted
+ Revision: 538144
- Mageia 4 Mass Rebuild

* Sat Sep 28 2013 pterjan <pterjan> 2.5.0.1-2.mga4
+ Revision: 488684
- Tag another arch specific header

* Thu Jun 20 2013 fwang <fwang> 2.5.0.1-1.mga4.tainted
+ Revision: 445176
- update dir
- add more br
- drop merged patch
- new version 2.5.0.1

* Sun Jun 16 2013 blino <blino> 2.4.12-2.mga4.tainted
+ Revision: 443649
- enable Adobe CFF hinting engine (like Fedora)

* Sun Jun 16 2013 blino <blino> 2.4.12-1.mga4
+ Revision: 443642
- drop CVE-2010-3311 patch (fixed in upstream commit 75787c19eab20874c5d588842c52e59cfbd9302a)
- 2.4.12
+ fwang <fwang>
- cleanup spec

* Fri Jan 11 2013 umeabot <umeabot> 2.4.11-2.mga3.tainted
+ Revision: 350959
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Dec 21 2012 fwang <fwang> 2.4.11-1.mga3.tainted
+ Revision: 333539
- new version 2.4.11

* Fri Jun 15 2012 fwang <fwang> 2.4.10-1.mga3.tainted
+ Revision: 260735
- new version 2.4.10

* Fri Mar 09 2012 fwang <fwang> 2.4.9-1.mga2.tainted
+ Revision: 221855
- new version 2.4.9

* Fri Mar 02 2012 dmorgan <dmorgan> 2.4.8-3.mga2.tainted
+ Revision: 216708
- Rebuild because of missing packages

* Fri Dec 16 2011 wally <wally> 2.4.8-2.mga2.tainted
+ Revision: 182614
- drop .la files

* Tue Nov 15 2011 fwang <fwang> 2.4.8-1.mga2.tainted
+ Revision: 167937
- new version 2.4.8

* Wed Oct 19 2011 fwang <fwang> 2.4.7-1.mga2.tainted
+ Revision: 156455
- new version 2.4.7
- new version 2.4.6

* Tue Jun 28 2011 fwang <fwang> 2.4.5-1.mga2.tainted
+ Revision: 115134
- new version 2.4.5

* Tue Jun 07 2011 ahmad <ahmad> 2.4.4-6.mga2.tainted
+ Revision: 101592
+ rebuild (emptylog)

* Tue May 31 2011 ahmad <ahmad> 2.4.4-5.mga2.tainted
+ Revision: 100820
- Enable tainted build
- Adapt the package(s) descriptions

* Fri Feb 25 2011 anssi <anssi> 2.4.4-4.mga1
+ Revision: 59964
- enable autohinting for fonts without bytecode (patch from upstream)

* Wed Feb 09 2011 tmb <tmb> 2.4.4-3.mga1
+ Revision: 49543
- rebuild for missing packages

* Sat Jan 08 2011 blino <blino> 2.4.4-2.mga1
+ Revision: 1032
- remove old ldconfig scriptlets
- imported package freetype2

